==> TruthDarePy-2.0.0.tar.gz: TruthDarePy-2.0.0/README.md <==
# Tg-Truth-Dare

# Installing Package
```
$ sh pip3 install -U TruthDarePy
```

# Example
```python3
# To Get List Of All Langauges
from TruthDarePy import TD as love
print(love.languages())

# Truth In English
from TruthDarePy import TD
love = TD()
print(love.truth(lang=en))

# Truth In Bengali
from TruthDarePy import TD
love = TD()
print(love.truth(lang=bn))

# Truth In German
from TruthDarePy import TD
love = TD()
print(love.truth(lang=de))

# Truth In Spanish
from TruthDarePy import TD
love = TD()
print(love.truth(lang=ea))

# Truth In French
from TruthDarePy import TD
love = TD()
print(love.truth(lang=fr))

# Truth In Hindi
from TruthDarePy import TD
love = TD()
print(love.truth(lang=hi))

# Truth In Filipino
from TruthDarePy import TD
love = TD()
print(love.truth(lang=tl))

# Dare In English
from TruthDarePy import TD
love = TD()
print(love.dare(lang=en))

# Dare In Bengali
from TruthDarePy import TD
love = TD()
print(love.dare(lang=bn))

# Dare In German
from TruthDarePy import TD
love = TD()
print(love.dare(lang=de))

# Dare In Spanish
from TruthDarePy import TD
love = TD()
print(love.dare(lang=ea))

# Dare In French
from TruthDarePy import TD
love = TD()
print(love.dare(lang=fr))

# Dare In Hindi
from TruthDarePy import TD
love = TD()
print(love.dare(lang=hi))

# Dare In Filipino
from TruthDarePy import TD
love = TD()
print(love.dare(lang=tl))
```

# Output
```
• English - en
• বাংলা (Bengali) - bn
• Deutsch (German) - de
• Español (Spanish) - ea
• Français (French) - fr
• हिंदी (Hindi) - hi
• Tagalog (Filipino) - tl
```

==> TruthDarePy-2.0.4.tar.gz: TruthDarePy-2.0.4/README.md <==
# Tg-Truth-Dare

# Installing Package
```
$ sh pip3 install -U TruthDarePy
```

# Example
```python3
# To Get List Of All Langauges
from TruthDarePy import TD as love
print(love.languages())

# Truth In English
from TruthDarePy import TD
love = TD()
print(love.truth(lang="en"))

# Truth In Bengali
from TruthDarePy import TD
love = TD()
print(love.truth(lang="bn"))

# Truth In German
from TruthDarePy import TD
love = TD()
print(love.truth(lang="de"))

# Truth In Spanish
from TruthDarePy import TD
love = TD()
print(love.truth(lang="ea"))

# Truth In French
from TruthDarePy import TD
love = TD()
print(love.truth(lang="fr"))

# Truth In Hindi
from TruthDarePy import TD
love = TD()
print(love.truth(lang="hi"))

# Truth In Filipino
from TruthDarePy import TD
love = TD()
print(love.truth(lang="tl"))

# Dare In English
from TruthDarePy import TD
love = TD()
print(love.dare(lang="en"))

# Dare In Bengali
from TruthDarePy import TD
love = TD()
print(love.dare(lang="bn"))

# Dare In German
from TruthDarePy import TD
love = TD()
print(love.dare(lang="de"))

# Dare In Spanish
from TruthDarePy import TD
love = TD()
print(love.dare(lang="ea"))

# Dare In French
from TruthDarePy import TD
love = TD()
print(love.dare(lang="fr"))

# Dare In Hindi
from TruthDarePy import TD
love = TD()
print(love.dare(lang="hi"))

# Dare In Filipino
from TruthDarePy import TD
love = TD()
print(love.dare(lang="tl"))
```

# Output
```
• English - en
• বাংলা (Bengali) - bn
• Deutsch (German) - de
• Español (Spanish) - ea
• Français (French) - fr
• हिंदी (Hindi) - hi
• Tagalog (Filipino) - tl
```
